Struct amazon_sp_fulfillment_outbound::models::get_feature_sku_result::GetFeatureSkuResult
source · [−]pub struct GetFeatureSkuResult {
pub marketplace_id: String,
pub feature_name: String,
pub is_eligible: bool,
pub ineligible_reasons: Option<Vec<String>>,
pub sku_info: Option<Box<FeatureSku>>,
}Expand description
GetFeatureSkuResult : The payload for the getFeatureSKU operation.
Fields
marketplace_id: StringThe requested marketplace.
feature_name: StringThe name of the feature.
is_eligible: boolWhen true, the seller SKU is eligible for the requested feature.
ineligible_reasons: Option<Vec<String>>A list of one or more reasons that the seller SKU is ineligibile for the feature. Possible values: * MERCHANT_NOT_ENROLLED - The merchant isn’t enrolled for the feature. * SKU_NOT_ELIGIBLE - The SKU doesn’t reside in a warehouse that supports the feature. * INVALID_SKU - There is an issue with the SKU provided.
sku_info: Option<Box<FeatureSku>>Implementations